package wallet

// ===================錢包餘額類型===================

// BalanceType 表示錢包餘額的類型
type BalanceType int64

// 錢包餘額類型
const (
	// AvailableBalanceType 表示可動用的餘額
	AvailableBalanceType BalanceType = iota + 1

	// FrozenBalanceType 表示在交易過程中凍結的餘額
	FrozenBalanceType

	// PendingBalanceType 表示已提交但尚未確認完成的交易餘額
	PendingBalanceType

	// ContractAvailableBalanceType 表示合約或交易可用的餘額
	ContractAvailableBalanceType

	// ContractFrozenBalanceType 表示合約或交易凍結的餘額
	ContractFrozenBalanceType
)

// balanceTypeToName 將餘額類型映射到其名稱
var balanceTypeToName = map[BalanceType]string{
	AvailableBalanceType:         "available",
	FrozenBalanceType:            "frozen",
	PendingBalanceType:           "pending",
	ContractAvailableBalanceType: "contract_available",
	ContractFrozenBalanceType:    "contract_frozen",
}

// nameToBalanceType 將名稱映射到餘額類型
var nameToBalanceType = map[string]BalanceType{
	"available":          AvailableBalanceType,
	"frozen":             FrozenBalanceType,
	"pending":            PendingBalanceType,
	"contract_available": ContractAvailableBalanceType,
	"contract_frozen":    ContractFrozenBalanceType,
}

// Name 返回餘額類型的名稱
func (b BalanceType) Name() string {
	return balanceTypeToName[b]
}

// GetBalanceTypeByName 根據名稱返回對應的餘額類型
func GetBalanceTypeByName(name string) BalanceType {
	return nameToBalanceType[name]
}

// AllBalanceTypes 包含目前所有的錢包餘額類型
var AllBalanceTypes = []BalanceType{
	AvailableBalanceType, FrozenBalanceType, PendingBalanceType,
	ContractAvailableBalanceType, ContractFrozenBalanceType,
}
